@@ -239,7 +239,7 @@ class EADSerialiser:
         self._serialise_maintenancestatus(ead_obj, control)
         self._serialise_publicationstatus(ead_obj, control)
         self._serialise_maintenanceagency(ead_obj, control)
-        for ld_obj in ead_obj.languagedeclarations.all():
+        for ld_obj in ead_obj.languagedeclaration_set.all():
             self._serialise_languagedeclaration(ld_obj, control)
         for cd_obj in ead_obj.conventiondeclaration_set.all():
             self._serialise_conventiondeclaration(cd_obj, control)
@@ -349,7 +349,7 @@ class EADSerialiser:
             self._serialise_physdescstructured(physdescstructured_obj, did)
         for physloc_obj in ead_obj.physloc_set.all():
             self._serialise_physloc(physloc_obj, did)
-        for repository_obj in ead_obj.repositories.all():
+        for repository_obj in ead_obj.repository_set.all():
             self._serialise_repository(repository_obj, did)
         for unitdate_obj in ead_obj.unitdate_set.all():
             self._serialise_unitdate(unitdate_obj, did)
@@ -585,13 +585,13 @@ class EADSerialiser:
     def _serialise_origination(self, origination_obj, did):
         origination = etree.SubElement(did, EAD + 'origination')
         serialise_attrs(origination_obj, ORIGINATION_ATTRS, origination)
-        for corpname_obj in origination_obj.corpnames.all():
+        for corpname_obj in origination_obj.corpname_set.all():
             self._serialise_name(corpname_obj, origination, 'corpname')
-        for famname_obj in origination_obj.famnames.all():
+        for famname_obj in origination_obj.famname_set.all():
             self._serialise_name(famname_obj, origination, 'famname')
-        for name_obj in origination_obj.names.all():
+        for name_obj in origination_obj.name_set.all():
             self._serialise_name(name_obj, origination, 'name')
-        for persname_obj in origination_obj.persnames.all():
+        for persname_obj in origination_obj.persname_set.all():
             self._serialise_name(persname_obj, origination, 'persname')
 
     def _serialise_otheragencycode(self, otheragencycode_obj,
@@ -739,13 +739,13 @@ class EADSerialiser:
     def _serialise_repository(self, repository_obj, did):
         repository = etree.SubElement(did, EAD + 'repository')
         serialise_attrs(repository_obj, REPOSITORY_ATTRS, repository)
-        for corpname_obj in repository_obj.corpnames.all():
+        for corpname_obj in repository_obj.corpname_set.all():
             self._serialise_name(corpname_obj, repository, 'corpname')
-        for famname_obj in repository_obj.famnames.all():
+        for famname_obj in repository_obj.famname_set.all():
             self._serialise_name(famname_obj, repository, 'famname')
-        for name_obj in repository_obj.names.all():
+        for name_obj in repository_obj.name_set.all():
             self._serialise_name(name_obj, repository, 'name')
-        for persname_obj in repository_obj.persnames.all():
+        for persname_obj in repository_obj.persname_set.all():
             self._serialise_name(persname_obj, repository, 'persname')
         addressline_objs = repository_obj.addressline_set.all()
         if addressline_objs:
